==> jc-1.4.0.tar.gz: java/security/cert/CertPathBuilder.h <==
// public class java.security.cert.CertPathBuilder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class dcc918ce6058b9e5 java_security_cert_CertPathBuilder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CertPathBuilder_H_
#define _JC_java_security_cert_CertPathBuilder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Provider$object;
struct _jc_java_security_cert_CertPathBuilder$object;
struct _jc_java_security_cert_CertPathBuilderResult$object;
struct _jc_java_security_cert_CertPathBuilderSpi$object;
struct _jc_java_security_cert_CertPathParameters$object;

// Typedefs
typedef struct _jc_java_security_cert_CertPathBuilder$sub_refs	_jc_java_security_cert_CertPathBuilder$sub_refs;
typedef struct _jc_java_security_cert_CertPathBuilder$sub_nonrefs	_jc_java_security_cert_CertPathBuilder$sub_nonrefs;
typedef struct _jc_java_security_cert_CertPathBuilder$refs	_jc_java_security_cert_CertPathBuilder$refs;
typedef struct _jc_java_security_cert_CertPathBuilder$nonrefs	_jc_java_security_cert_CertPathBuilder$nonrefs;
typedef struct _jc_java_security_cert_CertPathBuilder$object	_jc_java_security_cert_CertPathBuilder$object;

typedef struct _jc_java_security_cert_CertPathBuilder$fields_struct	_jc_java_security_cert_CertPathBuilder$fields_struct;
typedef const struct _jc_java_security_cert_CertPathBuilder$vmethods	_jc_java_security_cert_CertPathBuilder$vmethods;
typedef const struct _jc_java_security_cert_CertPathBuilder$vtable	_jc_java_security_cert_CertPathBuilder$vtable;
typedef const struct _jc_java_security_cert_CertPathBuilder$vtype	_jc_java_security_cert_CertPathBuilder$vtype;

// Class fields structure
struct _jc_java_security_cert_CertPathBuilder$fields_struct {
	struct _jc_java_lang_String$object	*CERT__5fPATH__5fBUILDER;
};
extern _jc_java_security_cert_CertPathBuilder$fields_struct _jc_java_security_cert_CertPathBuilder$class_fields;

// Constructors
extern void _jc_java_security_cert_CertPathBuilder$method$_init$075900960410f677(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *, struct _jc_java_security_cert_CertPathBuilderSpi$object *, struct _jc_java_security_Provider$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_java_security_cert_CertPathBuilder$method$build$4574a8b691d4bb14(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CertPathBuilder$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *);
extern struct _jc_java_security_Provider$object *_jc_java_security_cert_CertPathBuilder$method$getProvider$e8f9c9fb14140d5a(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertPathBuilder$method_info$build$4574a8b691d4bb14;
extern _jc_method _jc_java_security_cert_CertPathBuilder$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_java_security_cert_CertPathBuilder$method_info$getProvider$e8f9c9fb14140d5a;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CertPathBuilder$method$getDefaultType$e0168af0ff28954a(_jc_env *);
extern struct _jc_java_security_cert_CertPathBuilder$object *_jc_java_security_cert_CertPathBuilder$method$getInstance$3d723b3ff4fc9c0a(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_security_cert_CertPathBuilder$object *_jc_java_security_cert_CertPathBuilder$method$getInstance$4f778ca8c43e13c7(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_security_cert_CertPathBuilder$object *_jc_java_security_cert_CertPathBuilder$method$getInstance$a4e792b7efae009c(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_security_Provider$object *);

// Virtual methods structure
struct _jc_java_security_cert_CertPathBuilder$vmethods {
	struct _jc_object	*(*build$4574a8b691d4bb14)(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *);
	struct _jc_java_security_Provider$object	*(*getProvider$e8f9c9fb14140d5a)(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *);
};

// Vtable
struct _jc_java_security_cert_CertPathBuilder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertPathBuilder$vmethods	java_security_cert_CertPathBuilder;
};

// Vtype
struct _jc_java_security_cert_CertPathBuilder$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertPathBuilder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertPathBuilder$sub_refs {
	struct _jc_java_security_cert_CertPathBuilderSpi$object	*cpbSpi;
	struct _jc_java_security_Provider$object	*provider;
	struct _jc_java_lang_String$object	*algorithm;
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertPathBuilder$refs {
    _jc_java_security_cert_CertPathBuilder$sub_refs	java_security_cert_CertPathBuilder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertPathBuilder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertPathBuilder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertPathBuilder$sub_nonrefs	java_security_cert_CertPathBuilder;
};

// Object instance structure
struct _jc_java_security_cert_CertPathBuilder$object {
	_jc_java_security_cert_CertPathBuilder$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertPathBuilder$vtype	*vtype;
	_jc_java_security_cert_CertPathBuilder$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertPathBuilder$vtype _jc_java_security_cert_CertPathBuilder$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertPathBuilder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertPathBuilder$class_object;

#endif	/* _JC_java_security_cert_CertPathBuilder_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/CertPathBuilder.h <==
// public class java.security.cert.CertPathBuilder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class dcc918ce6058b9e5 java_security_cert_CertPathBuilder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CertPathBuilder_H_
#define _JC_java_security_cert_CertPathBuilder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Provider$object;
struct _jc_java_security_cert_CertPathBuilder$object;
struct _jc_java_security_cert_CertPathBuilderResult$object;
struct _jc_java_security_cert_CertPathBuilderSpi$object;
struct _jc_java_security_cert_CertPathParameters$object;

// Typedefs
typedef struct _jc_java_security_cert_CertPathBuilder$sub_refs	_jc_java_security_cert_CertPathBuilder$sub_refs;
typedef struct _jc_java_security_cert_CertPathBuilder$sub_nonrefs	_jc_java_security_cert_CertPathBuilder$sub_nonrefs;
typedef struct _jc_java_security_cert_CertPathBuilder$refs	_jc_java_security_cert_CertPathBuilder$refs;
typedef struct _jc_java_security_cert_CertPathBuilder$nonrefs	_jc_java_security_cert_CertPathBuilder$nonrefs;
typedef struct _jc_java_security_cert_CertPathBuilder$object	_jc_java_security_cert_CertPathBuilder$object;

typedef struct _jc_java_security_cert_CertPathBuilder$fields_struct	_jc_java_security_cert_CertPathBuilder$fields_struct;
typedef const struct _jc_java_security_cert_CertPathBuilder$vmethods	_jc_java_security_cert_CertPathBuilder$vmethods;
typedef const struct _jc_java_security_cert_CertPathBuilder$vtable	_jc_java_security_cert_CertPathBuilder$vtable;
typedef const struct _jc_java_security_cert_CertPathBuilder$vtype	_jc_java_security_cert_CertPathBuilder$vtype;

// Class fields structure
struct _jc_java_security_cert_CertPathBuilder$fields_struct {
	struct _jc_java_lang_String$object	*CERT__5fPATH__5fBUILDER;
};
extern _jc_java_security_cert_CertPathBuilder$fields_struct _jc_java_security_cert_CertPathBuilder$class_fields;

// Constructors
extern void _jc_java_security_cert_CertPathBuilder$method$_init$075900960410f677(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *, struct _jc_java_security_cert_CertPathBuilderSpi$object *, struct _jc_java_security_Provider$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_security_cert_CertPathBuilder$method$build$4574a8b691d4bb14(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CertPathBuilder$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_Provider$object *_jc_java_security_cert_CertPathBuilder$method$getProvider$e8f9c9fb14140d5a(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertPathBuilder$method_info$build$4574a8b691d4bb14;
extern _jc_method _jc_java_security_cert_CertPathBuilder$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_java_security_cert_CertPathBuilder$method_info$getProvider$e8f9c9fb14140d5a;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CertPathBuilder$method$getDefaultType$e0168af0ff28954a(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_security_cert_CertPathBuilder$object *_jc_java_security_cert_CertPathBuilder$method$getInstance$3d723b3ff4fc9c0a(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_cert_CertPathBuilder$object *_jc_java_security_cert_CertPathBuilder$method$getInstance$4f778ca8c43e13c7(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_cert_CertPathBuilder$object *_jc_java_security_cert_CertPathBuilder$method$getInstance$a4e792b7efae009c(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_security_Provider$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_security_cert_CertPathBuilder$vmethods {
	struct _jc_object	*(*build$4574a8b691d4bb14)(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_Provider$object	*(*getProvider$e8f9c9fb14140d5a)(_jc_env *, struct _jc_java_security_cert_CertPathBuilder$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_CertPathBuilder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertPathBuilder$vmethods	java_security_cert_CertPathBuilder;
};

// Vtype
struct _jc_java_security_cert_CertPathBuilder$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertPathBuilder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertPathBuilder$sub_refs {
	struct _jc_java_security_cert_CertPathBuilderSpi$object	*cpbSpi;
	struct _jc_java_security_Provider$object	*provider;
	struct _jc_java_lang_String$object	*algorithm;
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertPathBuilder$refs {
    _jc_java_security_cert_CertPathBuilder$sub_refs	java_security_cert_CertPathBuilder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertPathBuilder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertPathBuilder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertPathBuilder$sub_nonrefs	java_security_cert_CertPathBuilder;
};

// Object instance structure
struct _jc_java_security_cert_CertPathBuilder$object {
	_jc_java_security_cert_CertPathBuilder$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertPathBuilder$vtype	*vtype;
	_jc_java_security_cert_CertPathBuilder$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertPathBuilder$vtype _jc_java_security_cert_CertPathBuilder$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertPathBuilder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertPathBuilder$class_object;

#endif	/* _JC_java_security_cert_CertPathBuilder_H_ */
